\name{image.cel}
\alias{image.cel}
\title{Image of cel object}
\description{
  Displays an image of the data in a \code{\link{CEL}} object.
}
\usage{
  image.cel(cel, col=NULL, transfo=NULL, what="intensity",
                mask=NULL, transp=TRUE, ...)
}
\arguments{
  \item{cel}{a \code{\link{CEL}} object.}
  \item{col}{The colors to use for the image. If NULL, a scale of 64
    tones of grey are used.}
  \item{transfo}{a function to apply on the data to determine
    the colors (the effect is close to the \code{break} argument of the
    function \code{\link{image}}. It is probably a good idea to avoid the
    combined use of the \emph{transfo} and \emph{break} parameters).}
  \item{what}{which information in a \code{\link{CEL}} object is
    displayed. Unless 
    you add some, "intensity" and "sd" are the only kind of information
    held.}
  \item{mask}{an index of locations to mask when doing the
    plotting.}
  \item{transp}{is the data matrix transposed. If not, the data are
    flipped.}
  \item{...}{arguments to be passed to the underlying 'image' function.}
}
\author{
  Laurent Gautier}
}
\seealso{
  \code{\link{image.default}} (the R base image function called in turn by this function).
}
\examples{

  data(listcel)

  image(listcel[[1]])
  ## let's try to enhance a bit the contrasts
  image(listcel[[1]], transf=log)
  ## or why not
  image(listcel[[1]], transf=function(x){1/x})
  ## or even
  image(listcel[[1]], transf=function(x) {sqrt(x)}, col=rainbow(32))
}
\keyword{hplot}
