\name{read.affy}
\alias{read.affy}

\title{Data Input}
\description{Reads a file containing probe pair information in table format
  and creates an Affymetrix information object
  (\code{\link{probe.level.object}}).  Does not read CEL and CDF files.
}
\usage{
read.affy(file, chip, chip.names=NULL)
}
\arguments{
  \item{file}{the name of the file from which the data are to be
    read. This file must be in the format produced by the function 
    the \code{\link{cel2tab.pl}} perl script provided with this package.}
  \item{chip}{the name of the file from which to read the probe set names.}
  \item{chip.names}{character vector containing the names to be used
    for the different chips.}
}
\details{
  The function \code{\link{ReadAffy}} reads in directly from CEL and CDF
  files and the default reading function for affy.  This
  \code{\link{read.affy}} is
  useful only if you have preprocessed your  data into a table format in
  a flat file. 
  
  The file to be read must have a specific format. If \code{\link{cel2tab.pl}}
  are used one does not need to worry about this. 
  The first row of the file must contain the column names. These should
  be \code{id}, \code{number},  \code{pm.or.mm},  \code{x},
  \code{y}, and the names of the chips.
  The first five should be a 
  column  containing the probe id (which is related to a unique
  Affymetrix gene name), a
  column containing the probe number, a column containing a 1,0, -1 if the row corresponds to a pm,
  mm, or control respectively, a column with the probe row on the chip,
  and a column with the probe column on the chip. The rest of the
  columns should correspond to the intensities read for the
  different chips.

  If the chip.names are \code{NULL} the names of the CEL files will be
  used as chip.names.

}
\value{
  a \code{\link{probe.level.object}} }
\references{ Affymetrix (1999) Gene Chip Analysis Suite User Guide
  (Affymetrix, Santa Clara)}
\author{Rafael A. Irizarry}
\seealso{\code{\link{cel2tab.pl}},\code{\link{probe.level.object}}}
\keyword{file}




